package cn.com.infosec.asn1.util;

import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.BERConstructedOctetString;
import cn.com.infosec.asn1.BERConstructedSequence;
import cn.com.infosec.asn1.BERSequence;
import cn.com.infosec.asn1.BERSet;
import cn.com.infosec.asn1.BERTaggedObject;
import cn.com.infosec.asn1.DERBMPString;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERBoolean;
import cn.com.infosec.asn1.DERConstructedSequence;
import cn.com.infosec.asn1.DERConstructedSet;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERIA5String;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERPrintableString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERSet;
import cn.com.infosec.asn1.DERT61String;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.DERUTCTime;
import cn.com.infosec.asn1.DERUTF8String;
import cn.com.infosec.asn1.DERUnknownTag;
import cn.com.infosec.asn1.DERVisibleString;
import cn.com.infosec.util.encoders.Hex;
import java.util.Enumeration;

public class ASN1Dump {
   private static final String TAB = "    ";

   static String _dumpAsString(String indent, DERObject obj) {
      StringBuffer var10001;
      StringBuffer var2;
      Enumeration var3;
      String var4;
      Object indent1;
      if (!(obj instanceof ASN1Sequence)) {
         if (obj instanceof DERTaggedObject) {
            var10001 = var2 = new StringBuffer;
            String var10002 = indent;
            var2.<init>();
            indent = indent + "    ";
            var10001.append(var10002);
            if (obj instanceof BERTaggedObject) {
               var2.append("BER Tagged [");
            } else {
               var2.append("Tagged [");
            }

            DERTaggedObject obj1;
            var2.append(Integer.toString((obj1 = (DERTaggedObject)obj).getTagNo()));
            var2.append(']');
            if (!obj1.isExplicit()) {
               var2.append(" IMPLICIT ");
            }

            var2.append(System.getProperty("line.separator"));
            if (obj1.isEmpty()) {
               var2.append(indent);
               var2.append("EMPTY");
               var2.append(System.getProperty("line.separator"));
            } else {
               var2.append(_dumpAsString(indent, obj1.getObject()));
            }

            return var2.toString();
         } else {
            StringBuffer var10000;
            if (obj instanceof DERConstructedSet) {
               var10000 = var2 = new StringBuffer;
               var2.<init>();
               var3 = ((ASN1Set)obj).getObjects();
               var4 = indent + "    ";
               var10000.append(indent);
               var10000.append("ConstructedSet");
               var10000.append(System.getProperty("line.separator"));

               while(var3.hasMoreElements()) {
                  if ((indent1 = var3.nextElement()) == null) {
                     var2.append(var4);
                     var2.append("NULL");
                     var2.append(System.getProperty("line.separator"));
                  } else if (indent1 instanceof DERObject) {
                     var2.append(_dumpAsString(var4, (DERObject)indent1));
                  } else {
                     var2.append(_dumpAsString(var4, ((DEREncodable)indent1).getDERObject()));
                  }
               }

               return var2.toString();
            } else if (obj instanceof BERSet) {
               var10000 = var2 = new StringBuffer;
               var2.<init>();
               var3 = ((ASN1Set)obj).getObjects();
               var4 = indent + "    ";
               var10000.append(indent);
               var10000.append("BER Set");
               var10000.append(System.getProperty("line.separator"));

               while(var3.hasMoreElements()) {
                  if ((indent1 = var3.nextElement()) == null) {
                     var2.append(var4);
                     var2.append("NULL");
                     var2.append(System.getProperty("line.separator"));
                  } else if (indent1 instanceof DERObject) {
                     var2.append(_dumpAsString(var4, (DERObject)indent1));
                  } else {
                     var2.append(_dumpAsString(var4, ((DEREncodable)indent1).getDERObject()));
                  }
               }

               return var2.toString();
            } else if (obj instanceof DERSet) {
               var10000 = var2 = new StringBuffer;
               var2.<init>();
               var3 = ((ASN1Set)obj).getObjects();
               var4 = indent + "    ";
               var10000.append(indent);
               var10000.append("DER Set");
               var10000.append(System.getProperty("line.separator"));

               while(var3.hasMoreElements()) {
                  if ((indent1 = var3.nextElement()) == null) {
                     var2.append(var4);
                     var2.append("NULL");
                     var2.append(System.getProperty("line.separator"));
                  } else if (indent1 instanceof DERObject) {
                     var2.append(_dumpAsString(var4, (DERObject)indent1));
                  } else {
                     var2.append(_dumpAsString(var4, ((DEREncodable)indent1).getDERObject()));
                  }
               }

               return var2.toString();
            } else if (obj instanceof DERObjectIdentifier) {
               return indent + "ObjectIdentifier(" + ((DERObjectIdentifier)obj).getId() + ")" + System.getProperty("line.separator");
            } else if (obj instanceof DERBoolean) {
               return indent + "Boolean(" + ((DERBoolean)obj).isTrue() + ")" + System.getProperty("line.separator");
            } else if (obj instanceof DERInteger) {
               return indent + "Integer(" + ((DERInteger)obj).getValue() + ")" + System.getProperty("line.separator");
            } else if (obj instanceof BERConstructedOctetString) {
               return indent + "BER Constructed Octet String" + "[" + ((ASN1OctetString)obj).getOctets().length + "] " + System.getProperty("line.separator");
            } else if (obj instanceof DEROctetString) {
               return indent + "DER Octet String" + "[" + ((ASN1OctetString)obj).getOctets().length + "] " + System.getProperty("line.separator");
            } else if (obj instanceof DERBitString) {
               DERBitString indent3;
               return indent + "DER Bit String" + "[" + (indent3 = (DERBitString)obj).getBytes().length + ", " + indent3.getPadBits() + "] " + System.getProperty("line.separator");
            } else if (obj instanceof DERIA5String) {
               return indent + "IA5String(" + ((DERIA5String)obj).getString() + ") " + System.getProperty("line.separator");
            } else if (obj instanceof DERUTF8String) {
               return indent + "UTF8String(" + ((DERUTF8String)obj).getString() + ") " + System.getProperty("line.separator");
            } else if (obj instanceof DERPrintableString) {
               return indent + "PrintableString(" + ((DERPrintableString)obj).getString() + ") " + System.getProperty("line.separator");
            } else if (obj instanceof DERVisibleString) {
               return indent + "VisibleString(" + ((DERVisibleString)obj).getString() + ") " + System.getProperty("line.separator");
            } else if (obj instanceof DERBMPString) {
               return indent + "BMPString(" + ((DERBMPString)obj).getString() + ") " + System.getProperty("line.separator");
            } else if (obj instanceof DERT61String) {
               return indent + "T61String(" + ((DERT61String)obj).getString() + ") " + System.getProperty("line.separator");
            } else if (obj instanceof DERUTCTime) {
               return indent + "UTCTime(" + ((DERUTCTime)obj).getTime() + ") " + System.getProperty("line.separator");
            } else if (obj instanceof DERGeneralizedTime) {
               return indent + "GeneralizedTime(" + ((DERGeneralizedTime)obj).getTime() + ") " + System.getProperty("line.separator");
            } else {
               DERUnknownTag indent2;
               return obj instanceof DERUnknownTag ? indent + "Unknown " + Integer.toString((indent2 = (DERUnknownTag)obj).getTag(), 16) + " " + new String(Hex.encode(indent2.getData())) + System.getProperty("line.separator") : indent + obj.toString() + System.getProperty("line.separator");
            }
         }
      } else {
         var10001 = var2 = new StringBuffer;
         var2.<init>();
         var3 = ((ASN1Sequence)obj).getObjects();
         var4 = indent + "    ";
         var10001.append(indent);
         if (obj instanceof BERConstructedSequence) {
            var2.append("BER ConstructedSequence");
         } else if (obj instanceof DERConstructedSequence) {
            var2.append("DER ConstructedSequence");
         } else if (obj instanceof BERSequence) {
            var2.append("BER Sequence");
         } else if (obj instanceof DERSequence) {
            var2.append("DER Sequence");
         } else {
            var2.append("Sequence");
         }

         var2.append(System.getProperty("line.separator"));

         while(true) {
            while(var3.hasMoreElements()) {
               if ((indent1 = var3.nextElement()) != null && !indent1.equals(new DERNull())) {
                  if (indent1 instanceof DERObject) {
                     var2.append(_dumpAsString(var4, (DERObject)indent1));
                  } else {
                     var2.append(_dumpAsString(var4, ((DEREncodable)indent1).getDERObject()));
                  }
               } else {
                  var2.append(var4);
                  var2.append("NULL");
                  var2.append(System.getProperty("line.separator"));
               }
            }

            return var2.toString();
         }
      }
   }

   public static String dumpAsString(Object obj) {
      if (obj instanceof DERObject) {
         return _dumpAsString("", (DERObject)obj);
      } else {
         return obj instanceof DEREncodable ? _dumpAsString("", ((DEREncodable)obj).getDERObject()) : "unknown object type " + obj.toString();
      }
   }
}
